@@ -64,6 +64,11 @@ type cloneTemplateRepositoryInput struct {
 	IncludeAllBranches bool   `json:"includeAllBranches"`
 }
 
+type updateRepositoryInput struct {
+	RepositoryID   string `json:"repositoryId"`
+	HasWikiEnabled bool   `json:"hasWikiEnabled"`
+}
+
 // repoCreate creates a new GitHub repository
 func repoCreate(client *http.Client, hostname string, input repoCreateInput) (*api.Repository, error) {
 	isOrg := false
@@ -133,6 +138,27 @@ func repoCreate(client *http.Client, hostname string, input repoCreateInput) (*a
 			return nil, err
 		}
 
+		if !input.HasWikiEnabled {
+			updateVariables := map[string]interface{}{
+				"input": updateRepositoryInput{
+					RepositoryID:   response.CloneTemplateRepository.Repository.ID,
+					HasWikiEnabled: input.HasWikiEnabled,
+				},
+			}
+
+			if err := apiClient.GraphQL(hostname, `
+				mutation UpdateRepository($input: UpdateRepositoryInput!) {
+					updateRepository(input: $input) {
+						repository {
+							id
+						}
+					}
+				}
+			`, updateVariables, nil); err != nil {
+				return nil, err
+			}
+		}
+
 		return api.InitRepoHostname(&response.CloneTemplateRepository.Repository, hostname), nil
 	}
 
@@ -257,3 +283,9 @@ func listLicenseTemplates(httpClient *http.Client, hostname string) ([]api.Licen
 	}
 	return licenseTemplates, nil
 }
+
+// Returns the current username and any orgs that user is a member of.
+func userAndOrgs(httpClient *http.Client, hostname string) (string, []string, error) {
+	client := api.NewClientFromHTTP(httpClient)
+	return api.CurrentLoginNameAndOrgs(client, hostname)
+}
