@@ -6,6 +6,7 @@ import (
 	"fmt"
 	"io"
 	"net/http"
+	"net/url"
 	"testing"
 	"time"
 
@@ -1242,6 +1243,42 @@ func TestViewRun(t *testing.T) {
 			},
 			wantOut: "\nX trunk CI · 123\nTriggered via push about 59 minutes ago\n\nX This run likely failed because of a workflow file issue.\n\nFor more information, see: https://github.com/runs/123\n",
 		},
+		{
+			name: "Fetches all of a run's jobs with --json flag",
+			opts: &ViewOptions{
+				RunID: "3",
+				Exporter: shared.MakeTestExporter(
+					[]string{"jobs"},
+					func(io *iostreams.IOStreams, data interface{}) error {
+						run, ok := data.(*shared.Run)
+						if !ok {
+							return fmt.Errorf("expected data type *shared.Run")
+						}
+						fmt.Fprintf(io.Out, "fetched %d jobs\n", len(run.Jobs))
+						return nil
+					},
+				),
+			},
+			httpStubs: func(reg *httpmock.Registry) {
+				reg.Register(
+					httpmock.REST("GET", "repos/OWNER/REPO/actions/runs/3"),
+					httpmock.JSONResponse(shared.SuccessfulRun))
+				reg.Register(
+					httpmock.REST("GET", "repos/OWNER/REPO/actions/workflows/123"),
+					httpmock.JSONResponse(shared.TestWorkflow))
+				reg.Register(
+					httpmock.QueryMatcher("GET", "runs/3/jobs", url.Values{"per_page": []string{"100"}}),
+					httpmock.WithHeader(
+						httpmock.StringResponse(`{"jobs":[{},{},{}]}`),
+						"Link",
+						`<https://api.github.com/runs/3/jobs?page=2>; rel="next", <https://api.github.com/runs/3/jobs?page=2>; rel="last"`),
+				)
+				reg.Register(
+					httpmock.REST("GET", "runs/3/jobs"),
+					httpmock.StringResponse(`{"jobs":[{},{}]}`))
+			},
+			wantOut: "fetched 5 jobs\n",
+		},
 	}
 
 	for _, tt := range tests {
