@@ -11,14 +11,12 @@ import (
 	"sort"
 	"strings"
 
-	"github.com/AlecAivazis/survey/v2"
 	"github.com/MakeNowJust/heredoc"
 	"github.com/cli/cli/v2/api"
 	"github.com/cli/cli/v2/internal/ghrepo"
 	"github.com/cli/cli/v2/pkg/cmd/workflow/shared"
 	"github.com/cli/cli/v2/pkg/cmdutil"
 	"github.com/cli/cli/v2/pkg/iostreams"
-	"github.com/cli/cli/v2/pkg/prompt"
 	"github.com/spf13/cobra"
 	"gopkg.in/yaml.v3"
 )
@@ -27,6 +25,7 @@ type RunOptions struct {
 	HttpClient func() (*http.Client, error)
 	IO         *iostreams.IOStreams
 	BaseRepo   func() (ghrepo.Interface, error)
+	Prompter   iprompter
 
 	Selector  string
 	Ref       string
@@ -39,10 +38,16 @@ type RunOptions struct {
 	Prompt bool
 }
 
+type iprompter interface {
+	Input(string, string) (string, error)
+	Select(string, string, []string) (int, error)
+}
+
 func NewCmdRun(f *cmdutil.Factory, runF func(*RunOptions) error) *cobra.Command {
 	opts := &RunOptions{
 		IO:         f.IOStreams,
 		HttpClient: f.HttpClient,
+		Prompter:   f.Prompter,
 	}
 
 	cmd := &cobra.Command{
@@ -198,7 +203,7 @@ func (ia *InputAnswer) WriteAnswer(name string, value interface{}) error {
 	return fmt.Errorf("unexpected value type: %v", value)
 }
 
-func collectInputs(yamlContent []byte) (map[string]string, error) {
+func collectInputs(p iprompter, yamlContent []byte) (map[string]string, error) {
 	inputs, err := findInputs(yamlContent)
 	if err != nil {
 		return nil, err
@@ -210,32 +215,24 @@ func collectInputs(yamlContent []byte) (map[string]string, error) {
 		return providedInputs, nil
 	}
 
-	qs := []*survey.Question{}
-	for inputName, input := range inputs {
-		q := &survey.Question{
-			Name: inputName,
-			Prompt: &survey.Input{
-				Message: inputName,
-				Default: input.Default,
-			},
-		}
+	for _, input := range inputs {
+		var answer string
 		if input.Required {
-			q.Validate = survey.Required
+			for answer == "" {
+				answer, err = p.Input(input.Name+" (required)", input.Default)
+				if err != nil {
+					break
+				}
+			}
+		} else {
+			answer, err = p.Input(input.Name, input.Default)
 		}
-		qs = append(qs, q)
-	}
 
-	sort.Slice(qs, func(i, j int) bool {
-		return qs[i].Name < qs[j].Name
-	})
+		if err != nil {
+			return nil, err
+		}
 
-	inputAnswer := InputAnswer{
-		providedInputs: providedInputs,
-	}
-	//nolint:staticcheck // SA1019: prompt.SurveyAsk is deprecated: use Prompter
-	err = prompt.SurveyAsk(qs, &inputAnswer)
-	if err != nil {
-		return nil, err
+		providedInputs[input.Name] = answer
 	}
 
 	return providedInputs, nil
@@ -263,7 +260,7 @@ func runRun(opts *RunOptions) error {
 	}
 
 	states := []shared.WorkflowState{shared.Active}
-	workflow, err := shared.ResolveWorkflow(
+	workflow, err := shared.ResolveWorkflow(opts.Prompter,
 		opts.IO, client, repo, opts.Prompt, opts.Selector, states)
 	if err != nil {
 		var fae shared.FilteredAllError
@@ -290,7 +287,7 @@ func runRun(opts *RunOptions) error {
 		if err != nil {
 			return fmt.Errorf("unable to fetch workflow file content: %w", err)
 		}
-		providedInputs, err = collectInputs(yamlContent)
+		providedInputs, err = collectInputs(opts.Prompter, yamlContent)
 		if err != nil {
 			return err
 		}
@@ -330,12 +327,13 @@ func runRun(opts *RunOptions) error {
 }
 
 type WorkflowInput struct {
+	Name        string
 	Required    bool
 	Default     string
 	Description string
 }
 
-func findInputs(yamlContent []byte) (map[string]WorkflowInput, error) {
+func findInputs(yamlContent []byte) ([]WorkflowInput, error) {
 	var rootNode yaml.Node
 	err := yaml.Unmarshal(yamlContent, &rootNode)
 	if err != nil {
@@ -400,16 +398,31 @@ func findInputs(yamlContent []byte) (map[string]WorkflowInput, error) {
 		return nil, errors.New("unable to manually run a workflow without a workflow_dispatch event")
 	}
 
-	out := map[string]WorkflowInput{}
+	out := []WorkflowInput{}
+
+	m := map[string]WorkflowInput{}
 
 	if inputsKeyNode == nil || inputsMapNode == nil {
 		return out, nil
 	}
 
-	err = inputsMapNode.Decode(&out)
+	err = inputsMapNode.Decode(&m)
 	if err != nil {
 		return nil, fmt.Errorf("could not decode workflow inputs: %w", err)
 	}
 
+	for name, input := range m {
+		out = append(out, WorkflowInput{
+			Name:        name,
+			Default:     input.Default,
+			Description: input.Description,
+			Required:    input.Required,
+		})
+	}
+
+	sort.Slice(out, func(i, j int) bool {
+		return out[i].Name < out[j].Name
+	})
+
 	return out, nil
 }
